%    A panel with a map generated from a tile source.   
%   
%    CALL:   
%     obj = modelit.mapviewer.MapViewer(parent, varargin)   
%   
%    INPUT:   
%     parent: <handle>   
%       parent Figure   
%     varargin:   
%       property-value pairs with valid properties for a uipanel   
%       or the MapViewers tilesource.   
%   
%    OUTPUT:   
%     obj:   
%       modelit.mapviewer.MapViewer   
%   
%    EXAMPLE:   
%      m = modelit.mapviewer.MapViewer(gcf, 'visible', 'off');   
%      setVisibleRectangle(m, [ 2.4558   50.7183    5.7675    2.6999]);   
%   
%      COMPABILITY WITH AXES, MIGRATION ISSUES   
%      In many cases an application can be ported from "axes" based to   
%      "MapViewer" based by only replacing "axes" with "MapViewer" and   
%      making sure all line, text and patch command explictly specify   
%      the parent object. This makes sure that MapViewer methods line,   
%      text and patch are invoked.   
%      There are a view extra things to look out for.   
%      -1-   
%      A mapViewer object is not a Handle Graphics object. Its handle   
%      cannot be found through findobj.   
%      -2-   
%      Although MapViewer overloads plotting commands like line, patch   
%      and text, it does not automatically overload the set command for   
%      these objects.   
%      Example:   
%        h=line( ...'parent',map)   
%        set(h,'xdata',x,'ydata',y)   
%      This will not result in transforming x and y correctlty. Tip: use   
%      methods "getxydata" and "setxydata" instead.   
%      -3-   
%      Using "get" on object that are plotted ia MapViewer may not give   
%      a usefull result.   
%      Examples:   
%      get(h,'parent') returns axes handle, not MapViewer object. Tip:   
%      use HWIN=ancestor(hax,'figure') instead.   
%      get(h,'xdata') returns pixel coordinates not "real" coordinates   
%      -4-   
%      Only properties that are common to axes and uipanel (positional   
%      parameters) can be used in a call to MapViewer.   
%   
%   
%  modelit.mapviewer.MapViewer Properties:   
%    MAXTILES      - Maximum number of tiles to store in the array of tiles.   
%    type          - For inspection.   
%    EXPERIMENTAL  - Toggle between alphadata and contrast factor for testing   
%    contrast      - Number from 0-100 fading factor for the background 100 displays   
%    WGS84Corners  - When zooming out to maximum extent, zoom out to bounding box, or   
%    handle        - (Read only) Handle of the uipanel in which the map is displayed.   
%    tilelayer     - (Read only) Axis with tiles.   
%    currentPoint  - Location of mouse pointer   
%    xlim          - Minimum and maximum x-axis limits   
%    ylim          - Minimum and maximum y-axis limits   
%    ButtonDownFcn - Mouse-click callback   
%    hittest       - Respond to captured mouse clicks   
%    ZLim          - ZLim of layer axis   
%    PickableParts - Ability to capture mouse clicks   
%    UIContextMenu - ContextMenu   
%   
%  modelit.mapviewer.MapViewer Methods:   
%    delete              - DELETE   Delete a handle object.   
%    MapViewer           - A panel with a map generated from a tile source.   
%    getAxesHandle       - Return handle of data axes in mapviewer object (added   
%    isWGS               - Export WGS property of tile source   
%    LatToY              - Transforms latitude coordinate to pixel coordinate y   
%    LonToX              - Transforms longitude coordinate to pixel coordinate x   
%    YToLat              - Transforms pixel coordinate Y to latitude   
%    XToLon              - Transforms pixel coordinate X to longitude.   
%    setTilesource       - Set the source from which the map tiles are retrieved.   
%    setContrast         - Set contrast of tiles.   
%    colormap            - Redirect to layer.   
%    findobj             - Redirect findobj to axes created by MapViewer, so that line object   
%    lm_linkobj          - Redirect to Modelit lm_linkobj.   
%    zoomtool            - Redirect to Modelit zoomtool.   
%    text                - Plot text on the map.   
%    image               - Plot an image on the map.   
%    patch               - Plot a patch on the map.   
%    line                - Plot a line on the map.   
%    getxydata           - Get x or y data from object in the map.   
%    setxydata           - Set x or y data of object in the map.   
%    cla                 - Clear the axis with lines, patches and text.   
%    axes                - Activate axis with lines, patches and text.   
%    setZoomlevel        - Set the zoomlevel.   
%    getZoomlevel        - Get the zoomlevel.   
%    setPivotCenter      - Set pivot at relative coordinate xn, yn to coordinate lon,   
%    setCenter           - Set center of view.   
%    getCenter           - Get center of view.   
%    setVisibleRectangle - Set center and zoomlevel such that the given rectangle is completely visible.   
%    getVisibleRectangle - Get current view rectangle.   
%    getVisibleBox       - Get current coordinates of Mapviever viewport.   
%    setViewportCorners  - set viewport though lower-left and upper-right corner   
%    getViewportCorners  - get local coordinates of lower-left and upper-right corner of   
%    ancestor            - Get hg ancestor of this panel.   
%   
%  NOTE:   
%    Help automatically generated by classHelp (22-Nov-2021 13:41:04)   
   
   
% © Modelit 2006-2023   
% Matlab release: 2023a   
% Date: 2023/03/24 15:18:56   
